Package: SingleCaseES
Type: Package
Title: A Calculator for Single-Case Effect Sizes
Version: 0.7.4
Authors@R: c(
  person(c("James","E."), "Pustejovsky", email = "jepusto@gmail.com", role = c("aut", "cre")),
  person("Man", "Chen", email = "manchen9005@gmail.com", role = "aut"),
  person(c("Daniel","M."), "Swan", email = "dms031000@gmail.com", role = "aut"),
  person("Paulina", "Grekov", email = "grekov.paulina@gmail.com", role = "ctb"),
  person("Amy", "Cai", email = "amycai2023@gmail.com", role = "ctb")
  )
Description: 
  Provides R functions for calculating basic effect size indices for 
  single-case designs, including several non-overlap measures and parametric 
  effect size measures, and for estimating the gradual effects model developed 
  by Swan and Pustejovsky (2018) <DOI:10.1080/00273171.2018.1466681>. 
  Standard errors and confidence intervals (based on the assumption that the outcome 
  measurements are mutually independent) are provided for the subset of effect sizes 
  indices with known sampling distributions.
URL: https://jepusto.github.io/SingleCaseES/
BugReports: https://github.com/jepusto/SingleCaseES/issues
License: GPL-3
Depends: R (>= 4.1.0)
Imports: stats, purrr, dplyr, tidyr, rlang, tidyselect, utils
Suggests: spelling, shiny, shinytest2 (>= 0.5.0), stringr, rvest,
        ggplot2, purrrlyr, testthat, markdown, knitr, rmarkdown,
        cleanrmd, Kendall, kableExtra, covr, readxl, glue, janitor,
        rclipboard
LazyData: TRUE
RoxygenNote: 7.3.3
Encoding: UTF-8
Language: en-US
VignetteBuilder: knitr, rmarkdown, cleanrmd
NeedsCompilation: no
Packaged: 2026-04-02 14:49:47 UTC; jamespustejovsky
Author: James E. Pustejovsky [aut, cre],
  Man Chen [aut],
  Daniel M. Swan [aut],
  Paulina Grekov [ctb],
  Amy Cai [ctb]
Maintainer: James E. Pustejovsky <jepusto@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-02 15:20:02 UTC
Built: R 4.6.0; ; 2026-04-30 03:42:59 UTC; unix
