# gem_scd

Version (0.1.1) (2017-11-30)

Designed and built by Daniel M. Swan & James E. Pustejovsky

* dswan@utexas.edu

_Your comments, suggestions, and feedback are welcome._

### Suggested citation

Swan, Daniel M. & Pustejovsky, James E. (2016). gem_scd: A web-based calculator for the Gradual Effects Model (Version 0.1.1) [Web application]. Retrieved from: https://jepusto.shinyapps.io/gem-scd

### Paper

Swan, D. M., & Pustejovsky, J. E. (2017). A gradual effects model for single-case designs. https://doi.org/10.17605/OSF.IO/GAXRV
