---
output: md_document
knit: (knitr::knit)
---

# Single-case effect size calculator

Version `r packageVersion("SingleCaseES")`

Designed and built by James E. Pustejovsky, Man Chen, Paulina Grekov, & Daniel M. Swan.

-   <pustejovsky@wisc.edu>
-   <https://jepusto.com/>

[Source code available on Github](https://github.com/jepusto/SingleCaseES)

*Your comments, suggestions, and feedback are welcome.*

### Acknowledgement

<img src="https://raw.githubusercontent.com/jepusto/SingleCaseES/main/images/IES_InstituteOfEducationSciences_RGB.svg" width="30%" align = "right" style = "margin: 0px 10px" alt = "Institute of Education Sciences logo"/>

The development of this application was supported in part by the Institute of Education Sciences, U.S. Department of Education, through [Grant R324U190002](https://ies.ed.gov/funding/grantsearch/details.asp?ID=3358) to the University of Oregon. The contents of the application do not necessarily represent the views of the Institute or the U.S. Department of Education.

### Citation

Please cite this software as follows:

> Pustejovsky, J. E, Chen, M., Grekov, P., & Swan, D. M. (`r substr(packageDate("SingleCaseES"),1,4)`). 
> Single-case effect size calculator (Version `r packageVersion("SingleCaseES")`) 
> [Web application]. 
> <https://jepusto.shinyapps.io/SCD-effect-sizes/>
