# Example data

* McKissick, C., Hawkins, R. O., Lentz, F. E., Hailley, J., & McGuire, S. (2010). Randomizing multiple contingency components to decrease disruptive behaviors and increase student engagement in an urban second-grade classroom. _Psychology in the Schools, 47_(9), 944–959. https://doi.org/10.1002/pits.20516

* Olszewski, A., Soto, X., & Goldstein, H. (2017). Modeling alphabet skills as instructive feedback within a phonological awareness intervention. _American Journal of Speech-Language Pathology, 26_(3), 769–790. https://doi.org/10.1044/2017_AJSLP-16-0042

* Schmidt, A. C. (2007). The effects of a group contingency on group and individual behavior in an urban first-grade classroom. Masters Thesis, University of Kansas, Department of Applied Behavioral Sciences. ProQuest Dissertations & Theses Global, thesis number 1443719.

* Wright, L. A., & McCathren, R. B. (2012). Utilizing social stories to increase prosocial behavior and reduce 
problem behavior in young children with autism. _Child Development Research_, 2012, 1-13. https://doi.org/10.1155/2012/357291.
