# Example data

* Schmidt, C., & Stichter, J. P. (2012). The use of peer-mediated interventions to promote the generalization of social competence for adolescents with high-functioning autism and Asperger's syndrome. Exceptionality, 20(2), 94-113. doi:10.1080/09362835.2012
* Thorne, S., & Kamps, D. (2008). The effects of a group contingency intervention on academic engagement and problem behavior of at-risk students. Behavior Analysis in Practice, 1(2), 12-18.
